Package: ICAOD
Title: Optimal Designs for Nonlinear Models via ICA
Version: 1.0.2
Authors@R: c(person("Ehsan", "Masoudi", role = c("aut", "cre"),  email = "esn_mud@yahoo.com"),  person("Heinz", "Holling", role = "aut"),  person("Weng Kee", "Wong", role = "aut"), person("Seongho", "Kim", role = c("ctb")))
Description: Finds optimal designs for nonlinear models using a metaheuristic algorithm called Imperialist Competitive Algorithm (ICA). See, for details, Masoudi et al. (2022) <doi:10.32614/RJ-2022-043>, Masoudi et al. (2017) <doi:10.1016/j.csda.2016.06.014> and Masoudi et al. (2019) <doi:10.1080/10618600.2019.1601097>.
Depends: R (>= 4.4.0)
License: GPL (>= 2)
LinkingTo: Rcpp, RcppEigen
Imports: Rcpp, nloptr, stats, utils, graphics, grDevices, cubature, sn,
        mnormt, methods, mvQuad
Suggests: rgl, lattice, R.rsp
RoxygenNote: 7.3.3
Encoding: UTF-8
Language: en-US
NeedsCompilation: yes
Packaged: 2026-01-30 16:14:52 UTC; L078421
Author: Ehsan Masoudi [aut, cre],
  Heinz Holling [aut],
  Weng Kee Wong [aut],
  Seongho Kim [ctb]
Maintainer: Ehsan Masoudi <esn_mud@yahoo.com>
Repository: CRAN
Date/Publication: 2026-02-03 13:40:07 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-28 05:08:27 UTC; unix
Archs: ICAOD.so.dSYM
