# Generated by roxygen2: do not edit by hand

S3method(plot,minimax)
S3method(print,minimax)
S3method(print,sensminimax)
S3method(update,minimax)
export(FIM_2par_exp_censor1)
export(FIM_2par_exp_censor2)
export(FIM_3par_exp_censor1)
export(FIM_3par_exp_censor2)
export(FIM_exp_2par)
export(FIM_kinetics_alcohol)
export(FIM_logistic)
export(FIM_logistic_2pred)
export(FIM_logistic_4par)
export(FIM_loglin)
export(FIM_mixed_inhibition)
export(FIM_power_logistic)
export(FIM_sig_emax)
export(ICA.control)
export(bayes)
export(bayes.update)
export(bayescomp)
export(beff)
export(crt.bayes.control)
export(crt.minimax.control)
export(leff)
export(locally)
export(locallycomp)
export(meff)
export(minimax)
export(multiple)
export(normal)
export(robust)
export(sens.bayes.control)
export(sens.control)
export(sens.minimax.control)
export(sensbayes)
export(sensbayescomp)
export(senslocally)
export(senslocallycomp)
export(sensminimax)
export(sensmultiple)
export(sensrobust)
export(skewnormal)
export(student)
export(uniform)
importFrom(Rcpp,evalCpp)
importFrom(cubature,hcubature)
importFrom(grDevices,rainbow)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(methods,formalArgs)
importFrom(mnormt,dmt)
importFrom(mvQuad,createNIGrid)
importFrom(mvQuad,quadrature)
importFrom(mvQuad,rescale)
importFrom(nloptr,directL)
importFrom(nloptr,nl.opts)
importFrom(nloptr,nloptr)
importFrom(nloptr,nloptr.print.options)
importFrom(sn,dmsn)
importFrom(stats,as.formula)
importFrom(stats,binomial)
importFrom(stats,deriv)
importFrom(stats,gaussian)
importFrom(stats,optim)
importFrom(stats,runif)
importFrom(utils,capture.output)
useDynLib(ICAOD)
